#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage			 : http://www.nongnu.org/tpb/
# source location    : http://mirrors.zerg.biz/nongnu/tpb/tpb-0.6.4.tar.gz
# dependency         : 
# last revised       : 5.10.2009

softname='tpb'
softversion='0.6.4'
packageversion='1fb'

arch='i486'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://mirrors.zerg.biz/nongnu/tpb/$softname-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
tpb: tpb (A little program that enables you to use the IBM/Lenovo)
tpb:
tpb: With TPB it is possible to bind a program to the ThinkPad, Mail, 
tpb: Home and Search button. TPB can also run a callback program on each 
tpb: state change with the changed state and the new state as options. 
tpb: So it is possible to trigger several actions on different events.
tpb: 
tpb:
tpb: 
tpb:
tpb: 
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvzf $srcpkg
cd $src

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

make
make install DESTDIR=$dest

# add rules to start tpb
mv $dest/etc/tpbrc{,.new}

mkdir -p $dest/etc/udev/rules.d
cat $buildir/01-nvram.rules > $dest/etc/udev/rules.d/01-nvram.rules.new

# Add this to the doinst.sh:
! [ -d $dest/install ] && mkdir -p $dest/install
cat <<EOINS >> $dest/install/doinst.sh
# Handle the incoming configuration files:
config() {
  for infile in \$1; do
    NEW="\$infile"
    OLD="\`dirname \$NEW\`/\`basename \$NEW .new\`"
    # If there's no config file by that name, mv it over:
    if [ ! -r \$OLD ]; then
      mv \$NEW \$OLD
    elif [ "\`cat \$OLD | md5sum\`" = "\`cat \$NEW | md5sum\`" ]; then
      # toss the redundant copy
      rm \$NEW
    fi
    # Otherwise, we leave the .new copy for the admin to consider...
  done
}

# Handle '.new' config files:
config etc/tpbrc.new
config etc/udev/rules.d/01-nvram.rules.new

# Make sure tpb can work at all
if ! [ -e dev/nvram ]; then
  cat <<-EOM
	Please create the '/dev/nvram' device!
	Read the 'installation' section in /usr/doc/tpb-$VERSION/README.
	For Slackware with udev, run the commands:
	"/etc/rc.d/rc.udev reload" followed by
	"/sbin/modprobe nvram".
	Also add that second command to the file /etc/rc.d/rc.modules ,
	so that the 'dev/nvram' device is created on every boot.
	
	The '/dev/nvram' device must be readable by all. This package adds
	a UDEV rule that does this.
	EOM
fi

# Anyone using xdm/gdm/kdm will see tpb auto-started:
if ! grep "/usr/bin/tpb" etc/xprofile 1>/dev/null 2>&1 ; then
  cat <<-_EOM_ >> etc/xprofile
	
	# Load ThinkPad Buttons
	/usr/bin/tpb -d &
	
	_EOM_
fi

EOINS

# add 'default' files
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      THANKS INSTALL README COPYING AUTHORS ChangeLog\
      $dest/usr/doc/$softname-$softversion

# strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# SalixBuild
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "e2fsprogs,libICE,libSM,libX11,libXau,libXdmcp,libXext,\
libXinerama,libxcb,libxosd" > $package.dep

# erase
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
